MultiImage<T> class

Annotations
  • @freezed

Constructors

MultiImage({@Default.new([]) List<T> images, @Default.new([]) List<Asset> assets})
const
factory

Properties

assets → List<Asset>
no setterinherited
copyWith → $MultiImageCopyWith<T, MultiImage<T>>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
images → List<T>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited